@@ -4,6 +4,8 @@ Class to hold miscellaneous but useful decorators for our framework
 
 from inspect import getfullargspec
 
+import pytest
+
 
 class Wrapit():
     "Wrapit class to hold decorator functions"
@@ -44,13 +46,20 @@ class Wrapit():
             # If not return boolean, skip screenshot
             if args[0].screenshot == 'all':
                 screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
-                args[0].screenshot_counter = 0
-                args[0].name_ = func.__name__
+                args[0].screenshot_counter += 1
+                screenshot = args[0].get_screenshot_as_png()
                 args[0].save_screenshot(screenshot_name)
+                pytest.config.pluginmanager.get_plugin("html").attach(name="Screenshot", contents=screenshot,
+                                                                      extension=".png")
+
             elif args[0].screenshot == 'failonly' and result is False:
                 screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
                 args[0].screenshot_counter += 1
+                screenshot = args[0].get_screenshot_as_png()
                 args[0].save_screenshot(screenshot_name)
+                pytest.config.pluginmanager.get_plugin("html").attach(name="Screenshot", contents=screenshot,
+                                                                      extension=".png")
+
             return result
 
         return wrapper
